# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.12.0~f6f9756',
    built_at='2024-11-07 09:41:11Z',
    sha='f6f975677676e5749b1e9cc97a0fb9238f18097a',
    branch='HEAD',
    tag='v4.12.0',
)
